@@ -1,7 +1,7 @@
 /*
  * fmtx-faker: Tricks fmtxd into thinking the transmitter is not disabled.
  *
- * Copyright (C) 2009 Faheem Pervez <trippin1@gmail.com>. All rights reserved.
+ * Copyright (C) 2009-2010 Faheem Pervez <trippin1@gmail.com>. All rights reserved.
  *
  *             DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
  *                   Version 2, December 2004
@@ -206,43 +206,26 @@ gboolean fmtx_faker_get_config_value (FMTXFaker *self, const gchar *string, GArr
 		#define SYSINFO_INTERFACE_DBUS "com.nokia.SystemInfo"
 		#define SYSINFO_METHOD "GetConfigValue"		
 
-		DBusGConnection  *sys_connection;
+		DBusGConnection *sys_connection = FMTX_FAKER_GET_PRIVATE (self)->dbus_connection;
 		DBusGProxy *sysinfo_proxy;
-		GError *tmp_error = NULL; 
-		
-		sys_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &tmp_error);
-		if (tmp_error)
-		{
-			g_propagate_error (error, tmp_error);
-			goto ret;
-		}
 
 		sysinfo_proxy = dbus_g_proxy_new_for_name (sys_connection, SYSINFO_SERVICE_DBUS, SYSINFO_PATH_DBUS, SYSINFO_INTERFACE_DBUS);
 		if (!sysinfo_proxy)
 		{
-			dbus_g_connection_unref (sys_connection);
 			g_set_error (error, DBUS_GERROR, DBUS_GERROR_REMOTE_EXCEPTION, "Couldn't create SystemInfo proxy");
 			goto ret;
 		}
 		
-		dbus_g_proxy_call (sysinfo_proxy, SYSINFO_METHOD, &tmp_error, G_TYPE_STRING, string, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UCHAR), out_array, G_TYPE_INVALID);
-		if (tmp_error)
-		{
-			g_object_unref (G_OBJECT (sysinfo_proxy));
-			dbus_g_connection_unref (sys_connection);
-			g_propagate_error (error, tmp_error);
-			goto ret;
-		}
-
+		dbus_g_proxy_call (sysinfo_proxy, SYSINFO_METHOD, error, G_TYPE_STRING, string, G_TYPE_INVALID, dbus_g_type_get_collection ("GArray", G_TYPE_UCHAR), out_array, G_TYPE_INVALID);
 		g_object_unref (G_OBJECT (sysinfo_proxy));
-		dbus_g_connection_unref (sys_connection);
 
-		retval = TRUE;
+		if (!*error)
+			retval = TRUE;
 	}
 
 ret:
 	g_idle_add ((GSourceFunc) fmtx_faker_shutdown, self);
-	g_return_val_if_reached (retval);
+	return retval;
 }
 
 FMTXFaker* fmtx_faker_new_with_fmtx_mode_property (const guchar value)
